@@ -2,7 +2,7 @@
 # -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
 #   Catfish - a versatile file searching tool
 #   Copyright (C) 2007-2012 Christian Dywan <christian@twotoasts.de>
-#   Copyright (C) 2012-2019 Sean Davis <smd.seandavis@gmail.com>
+#   Copyright (C) 2012-2019 Sean Davis <bluesabre@xfce.org>
 #
 #   This program is free software: you can redistribute it and/or modify it
 #   under the terms of the GNU General Public License version 2, as published
@@ -310,7 +310,7 @@ class CatfishSearchMethod_Walk(CatfishSearchMethod):
         self.running = True
         if isinstance(keywords, str):
             keywords = keywords.replace(',', ' ').strip().split()
-        for root, dirs, files in os.walk(path, False):
+        for root, dirs, files in os.walk(path):
             dirs[:] = [d for d in dirs if os.path.join(root, d) not in exclude]
             if not self.running:
                 break
@@ -547,9 +547,33 @@ class CatfishSearchMethod_Locate(CatfishSearchMethodExternal):
     def __init__(self):
         """Initialize the Locate SearchMethod."""
         CatfishSearchMethodExternal.__init__(self, "locate")
-        self.command = ["locate", "-i", "%path*%keywords*", "--existing"]
+        self.caps = self.get_capabilities()
+        if self.caps["existing"]:
+            self.command = ["locate", "-i", "%path*%keywords*", "--existing"]
+        else:
+            self.command = ["locate", "-i", "%path*%keywords*"]
+
+    def get_capabilities(self):
+        caps = {
+            "existing": False,
+            "regex": False
+        }
+        try:
+            details = subprocess.check_output(["locate", "--help"])
+            details = details.decode("utf-8")
+            if "--existing" in details:
+                caps["existing"] = True
+            if "--regex" in details or "--regexp" in details:
+                caps["regex"] = True
+
+        except subprocess.CalledProcessError:
+            pass
+        return caps
 
     def assemble_query(self, keywords, path):
         """Assemble the search query."""
-        return ["locate", "--regex", "--basename", "-i",
-                "{}".format(string_regex(keywords, path))]
+        if self.caps["regex"]:
+            return ["locate", "--regex", "--basename", "-i",
+                    "{}".format(string_regex(keywords, path))]
+        else:
+            return ["locate", "-i", "%path*", str(keywords)]
